@@ -20,8 +20,7 @@ namespace binding {
  *
  * Table API
  */
-std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor, t_val computed, std::uint32_t limit, py::str index, t_op op, bool is_update, bool is_arrow);
-std::shared_ptr<Table> make_computed_table_py(std::shared_ptr<Table> table, t_val computed);
+std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor, std::uint32_t limit, py::str index, t_op op, bool is_update, bool is_arrow, t_uindex port_id);
 
 } //namespace binding
 } //namespace perspective
