@@ -17,7 +17,7 @@ namespace numpy {
 
     const std::vector<std::string> NumpyLoader::DATE_UNITS = {"[D]", "[W]", "[M]", "[Y]"};
 
-    NumpyLoader::NumpyLoader(py::object accessor)
+    NumpyLoader::NumpyLoader(t_val accessor)
         : m_init(false)
         , m_accessor(accessor) {}
 
@@ -386,6 +386,7 @@ namespace numpy {
             }
 
             auto date_components = item.cast<std::map<std::string, std::int32_t>>();
+            // date_components["month"] should be [0-11]
             t_date dt = t_date(date_components["year"], date_components["month"], date_components["day"]);
             col->set_nth(i, dt);
         }
