@@ -192,7 +192,7 @@ class View(object):
         Multiple callbacks can be set through calling ``on_update`` multiple
         times, and will be called in the order they are set. Callback must be a
         callable function that takes exactly 1 or 2 parameters, depending on
-        whether `on_update` is called with `mode="rows"`. The first parameter is
+        whether `on_update` is called with `mode="row"`. The first parameter is
         always `port_id`, an :obj:`int` that indicates which input port the
         update comes from. A `RuntimeError` will be thrown if the callback
         has mis-configured parameters.
@@ -200,7 +200,7 @@ class View(object):
         Args:
             callback (:obj:`callable`): a callable function reference that will
                 be called when :func:`perspective.Table.update()` is called.
-            mode (:obj:`str`): if set to "rows", the callback will be passed
+            mode (:obj:`str`): if set to "row", the callback will be passed
                 an Arrow-serialized dataset of the rows that were updated.
                 Defaults to "none".
 
@@ -255,7 +255,7 @@ class View(object):
         self._table._state_manager.call_process(self._table._table.get_id())
         if not callable(callback):
             return ValueError("remove_update callback should be a callable function!")
-        self._callbacks.remove_callbacks(lambda cb: cb["orig_callback"] != callback)
+        self._callbacks.remove_callbacks(lambda cb: cb["orig_callback"] == callback)
 
     def on_delete(self, callback):
         '''Set a callback to be run when the :func:`perspective.View.delete()`
@@ -292,8 +292,8 @@ class View(object):
         self._table._state_manager.remove_process(self._table._table.get_id())
         self._table._views.pop(self._table._views.index(self._name))
         # remove the callbacks associated with this view
-        self._callbacks.remove_callbacks(lambda cb: cb["name"] != self._name)
-        [cb() for cb in self._delete_callbacks.get_callbacks()]
+        self._callbacks.remove_callbacks(lambda cb: cb["name"] == self._name)
+        [cb() for cb in self._delete_callbacks]
 
     def remove_delete(self, callback):
         '''Remove the delete callback associated with this
@@ -318,7 +318,7 @@ class View(object):
         '''
         if not callable(callback):
             return ValueError("remove_delete callback should be a callable function!")
-        self._delete_callbacks.remove_callbacks(lambda cb: cb != callback)
+        self._delete_callbacks.remove_callbacks(lambda cb: cb == callback)
 
     def to_arrow(self, **kwargs):
         options = _parse_format_options(self, kwargs)
