@@ -10,6 +10,7 @@ import pandas as pd
 import numpy as np
 from perspective.table import Table
 from datetime import date, datetime
+from pytest import mark
 
 
 def compare_delta(received, expected):
@@ -43,8 +44,8 @@ class TestView(object):
         }
         assert view.to_records() == [
             {"__ROW_PATH__": [], "a": 4, "b": 6},
-            {"__ROW_PATH__": ["1"], "a": 1, "b": 2},
-            {"__ROW_PATH__": ["3"], "a": 3, "b": 4}
+            {"__ROW_PATH__": [1], "a": 1, "b": 2},
+            {"__ROW_PATH__": [3], "a": 3, "b": 4}
         ]
 
     def test_view_two(self):
@@ -59,8 +60,8 @@ class TestView(object):
         }
         assert view.to_records() == [
             {"2|a": 1, "2|b": 2, "4|a": 3, "4|b": 4, "__ROW_PATH__": []},
-            {"2|a": 1, "2|b": 2, "4|a": None, "4|b": None, "__ROW_PATH__": ["1"]},
-            {"2|a": None, "2|b": None, "4|a": 3, "4|b": 4, "__ROW_PATH__": ["3"]}
+            {"2|a": 1, "2|b": 2, "4|a": None, "4|b": None, "__ROW_PATH__": [1]},
+            {"2|a": None, "2|b": None, "4|a": 3, "4|b": 4, "__ROW_PATH__": [3]}
         ]
 
     def test_view_two_column_only(self):
@@ -236,6 +237,20 @@ class TestView(object):
         assert view.num_columns() == 0
         assert view.to_records() == [{}, {}]
 
+    def test_view_no_columns_pivoted(self):
+        data = [{"a": 1, "b": 2}, {"a": 3, "b": 4}]
+        tbl = Table(data)
+        view = tbl.view(row_pivots=["a"], columns=[])
+        assert view.num_columns() == 0
+        assert view.to_records() == [
+            {
+                "__ROW_PATH__": []
+            }, {
+                "__ROW_PATH__": [1]
+            }, {
+                "__ROW_PATH__": [3]
+            }]
+
     def test_view_specific_column(self):
         data = [{"a": 1, "b": 2, "c": 3, "d": 4}, {"a": 3, "b": 4, "c": 5, "d": 6}]
         tbl = Table(data)
@@ -302,8 +317,8 @@ class TestView(object):
         )
         assert view.to_records() == [
             {"__ROW_PATH__": []},
-            {"__ROW_PATH__": ["1"]},
-            {"__ROW_PATH__": ["3"]}
+            {"__ROW_PATH__": [1]},
+            {"__ROW_PATH__": [3]}
         ]
 
     def test_view_aggregates_column_order(self):
@@ -320,13 +335,50 @@ class TestView(object):
         order = ["__ROW_PATH__", "a", "c"]
         assert view.column_paths() == order
 
-    def test_view_column_pivot_datetime_names(self):
+    # row and column pivot paths
+    def test_view_row_pivot_datetime_row_paths_are_same_as_data(self):
+        """Tests row paths for datetimes in UTC. Timezone-related tests are
+        in the `test_table_datetime` file."""
+        data = {"a": [datetime(2019, 7, 11, 12, 30)], "b": [1]}
+        tbl = Table(data)
+        view = tbl.view(row_pivots=["a"])
+        data = view.to_dict()
+
+        for rp in data["__ROW_PATH__"]:
+            if len(rp) > 0:
+                assert rp[0] == datetime(2019, 7, 11, 12, 30)
+
+        assert tbl.view().to_dict() == {
+            "a": [datetime(2019, 7, 11, 12, 30)], "b": [1]
+        }
+
+    def test_view_column_pivot_datetime_names_utc(self):
+        """Tests column paths for datetimes in UTC. Timezone-related tests are
+        in the `test_table_datetime` file."""
         data = {"a": [datetime(2019, 7, 11, 12, 30)], "b": [1]}
         tbl = Table(data)
         view = tbl.view(column_pivots=["a"])
-        cols = list(view.to_dict().keys())
-        for col in cols:
-            assert col in ["2019-07-11 12:30:00.000|a", "2019-07-11 12:30:00.000|b"]
+        cols = view.column_paths()
+        assert cols == ["2019-07-11 12:30:00.000|a", "2019-07-11 12:30:00.000|b"]
+
+    def test_view_column_pivot_datetime_names_min(self):
+        """Tests column paths for datetimes in UTC. Timezone-related tests are
+        in the `test_table_datetime` file."""
+        data = {"a": [datetime.min], "b": [1]}
+        tbl = Table(data)
+        view = tbl.view(column_pivots=["a"])
+        cols = view.column_paths()
+        assert cols == ["1970-01-01 00:00:00.000|a", "1970-01-01 00:00:00.000|b"]
+
+    @mark.skip
+    def test_view_column_pivot_datetime_names_max(self):
+        """Tests column paths for datetimes in UTC. Timezone-related tests are
+        in the `test_table_datetime` file."""
+        data = {"a": [datetime.max], "b": [1]}
+        tbl = Table(data)
+        view = tbl.view(column_pivots=["a"])
+        cols = view.column_paths()
+        assert cols == ["10000-01-01 00:00:00.000|a", "10000-01-01 00:00:00.000|b"]
 
     # aggregate
 
@@ -339,8 +391,8 @@ class TestView(object):
         )
         assert view.to_records() == [
             {"__ROW_PATH__": [], "a": 2.0, "b": 6},
-            {"__ROW_PATH__": ["1"], "a": 1.0, "b": 2},
-            {"__ROW_PATH__": ["3"], "a": 3.0, "b": 4}
+            {"__ROW_PATH__": [1], "a": 1.0, "b": 2},
+            {"__ROW_PATH__": [3], "a": 3.0, "b": 4}
         ]
 
     def test_view_aggregate_str(self):
@@ -365,7 +417,7 @@ class TestView(object):
         )
         assert view.to_records() == [
             {"__ROW_PATH__": [], "a": 1},
-            {"__ROW_PATH__": ["2019-10-01 11:30:00.000"], "a": 1}
+            {"__ROW_PATH__": [datetime(2019, 10, 1, 11, 30)], "a": 1}
         ]
 
     def test_view_aggregate_datetime_leading_zeroes(self):
@@ -377,7 +429,7 @@ class TestView(object):
         )
         assert view.to_records() == [
             {"__ROW_PATH__": [], "a": 1},
-            {"__ROW_PATH__": ["2019-01-01 05:05:05.000"], "a": 1}
+            {"__ROW_PATH__": [datetime(2019, 1, 1, 5, 5, 5)], "a": 1}
         ]
 
     def test_view_aggregate_multiple_columns(self):
@@ -730,7 +782,7 @@ class TestView(object):
         view.on_update(cb2)
         view.on_update(cb1)
         view.remove_update(cb1)
-        assert len(view._callbacks.get_callbacks()) == 1
+        assert len(view._callbacks) == 1
         tbl.update(data)
         assert s.get() == 2
 
@@ -767,7 +819,7 @@ class TestView(object):
         tbl = Table(data)
         view = tbl.view(row_pivots=["a"])
         assert view.to_dict() == {
-            "__ROW_PATH__": [[], ["1"], ["3"]],
+            "__ROW_PATH__": [[], [1], [3]],
             "a": [4, 1, 3],
             "b": [6, 2, 4]
         }
@@ -794,7 +846,7 @@ class TestView(object):
         tbl = Table(data)
         view = tbl.view(row_pivots=["a"], column_pivots=["b"])
         assert view.to_dict() == {
-            "__ROW_PATH__": [[], ["1"], ["3"]],
+            "__ROW_PATH__": [[], [1], [3]],
             "2|a": [1, 1, None],
             "2|b": [2, 2, None],
             "4|a": [3, None, 3],
